@@ -17,10 +17,21 @@ A simple app configuration scheme using YAML and class based defaults.
 ## Imports
 ##########################################################################
 
-from .config import Configuration
+from .config import Configuration, environ_setting
+from .exceptions import ImproperlyConfigured
 
 ##########################################################################
-## Module Constants
+## Package constants
 ##########################################################################
 
-__version__ = "0.1.1"
+__version__ = (0, 2, 0)
+
+##########################################################################
+## Package helpers
+##########################################################################
+
+def get_version():
+    """
+    Returns a string containing the version number
+    """
+    return ".".join("%i" % idx for idx in __version__)
